@@ -8,4 +8,4 @@ mod util;
 // Tests themselves.
 mod test_config;
 mod test_hook;
-mod test_prefix;
+mod test_signature;
